==> haskell-regex-applicative-0.3.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-WxA98eIqTU6IYmhPidLpN
key: regex-applicative-0.3.3-WxA98eIqTU6IYmhPidLpN
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
author: Roman Cheplyaka
exposed: True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Object
    Text.Regex.Applicative.Common Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
abi: ce606b8e96e746dc15e8a00a3aabe03c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-applicative-0.3.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-WxA98eIqTU6IYmhPidLpN
depends:
    base-4.9.0.0 containers-0.5.7.1 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-applicative
version: 0.3.3
id: regex-applicative-0.3.3-9dbODILokN54la9GS4TJob
key: regex-applicative-0.3.3-9dbODILokN54la9GS4TJob
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/regex-applicative
synopsis: Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.
category: Text
author: Roman Cheplyaka
exposed: True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Object
    Text.Regex.Applicative.Common Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue
hidden-modules: Text.Regex.Applicative.Interface
                Text.Regex.Applicative.Types Text.Regex.Applicative.Compile
abi: befb57bc0d95e9186b7c2d1ee6aaec6b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/regex-applicative-0.3.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/regex-applicative-0.3.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/regex-applicative-0.3.3
hs-libraries: HSregex-applicative-0.3.3-9dbODILokN54la9GS4TJob
depends:
    base-4.9.1.0 containers-0.5.7.1 transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock
haddock-html: /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
